==> openflowplugin-extension-nicira-0.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/output/to/port/_case/FlowModOutputToPort.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-output-to-port {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case/flow-mod-output-to-port</i>
 *
 * <p>To create instances of this class use {@link FlowModOutputToPortBuilder}.
 * @see FlowModOutputToPortBuilder
 *
 */
public interface FlowModOutputToPort
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModOutputToPort>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort.class;
    }
    
    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    @Nullable Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    @Nullable Integer getSrcOfs();

}

==> openflowplugin-extension-nicira-0.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/output/to/port/_case/FlowModOutputToPort.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint16;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-output-to-port {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case/flow-mod-output-to-port</i>
 *
 * <p>To create instances of this class use {@link FlowModOutputToPortBuilder}.
 * @see FlowModOutputToPortBuilder
 *
 */
public interface FlowModOutputToPort
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModOutputToPort>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getFlowModNumBits();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>srcField</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getSrcField();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getSrcOfs();

}
